@@ -1,10 +1,9 @@
 package service
 
 import (
+	"context"
 	"fmt"
 
-	"golang.org/x/net/context"
-
 	"github.com/docker/swarmkit/api"
 )
 
