@@ -2,6 +2,7 @@ package integration
 
 import (
 	"bytes"
+	"context"
 	"flag"
 	"fmt"
 	"io/ioutil"
@@ -14,8 +15,6 @@ import (
 
 	"github.com/docker/swarmkit/node"
 
-	"golang.org/x/net/context"
-
 	"reflect"
 
 	"github.com/cloudflare/cfssl/helpers"
@@ -63,6 +62,23 @@ func TestMain(m *testing.M) {
 	os.Exit(res)
 }
 
+// newTestCluster creates new cluster to which nodes can be added.
+// AcceptancePolicy is set to most permissive mode on first manager node added.
+func newTestCluster(testname string, fips bool) *testCluster {
+	ctx, cancel := context.WithCancel(context.Background())
+	ctx = context.WithValue(ctx, testnameKey, testname)
+	c := &testCluster{
+		ctx:        ctx,
+		cancel:     cancel,
+		nodes:      make(map[string]*testNode),
+		nodesOrder: make(map[string]int),
+		errs:       make(chan error, 1024),
+		fips:       fips,
+	}
+	c.api = &dummyAPI{c: c}
+	return c
+}
+
 // pollClusterReady calls control api until all conditions are true:
 // * all nodes are ready
 // * all managers has membership == accepted
